@@ -10,6 +10,10 @@ pub enum Error {
     TokioJoinError(String),
     #[error("{0}: Invalid HTTP response")]
     InvalidHttpResponse(String),
+    #[error("{0} is not a valid output format. Valid values are [text, json].")]
+    InvalidOutputFormat(String),
+    #[error("Error serializing to JSON: {0}")]
+    SerializingJson(String),
 }
 
 impl std::convert::From<reqwest::Error> for Error {
@@ -23,3 +27,9 @@ impl std::convert::From<tokio::task::JoinError> for Error {
         Error::TokioJoinError(err.to_string())
     }
 }
+
+impl std::convert::From<serde_json::Error> for Error {
+    fn from(err: serde_json::Error) -> Self {
+        Error::SerializingJson(err.to_string())
+    }
+}
